﻿Public Class Form1

    Private Declare Sub Sleep Lib "Kernel32" (ByVal dwMilliseconds As Integer)

    Dim checkboxAi(0 To 23) As CheckBox
    Dim textboxAiValue(0 To 23) As TextBox
    Dim checkboxDi(0 To 3) As CheckBox
    Dim checkboxDo(0 To 3) As CheckBox

    Dim DevIndex As Integer
    Dim bRun As Boolean


    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        Dim temp As Integer
        Dim i As Integer

        temp = FindUSB3DAQ()
        If (temp > 0) Then

            For i = 0 To temp - 1
                comboboxDeviceIndex.Items.Add(i)
            Next

            comboboxDeviceIndex.SelectedIndex = 0
            btnStart.Enabled = True
        Else
            btnStart.Enabled = False
        End If

        For i = 0 To 23
            checkboxAi(i) = New CheckBox
            checkboxAi(i).Width = 60
            checkboxAi(i).Text = "Ai " & i.ToString
            checkboxAi(i).Left = 20 + 75 * (i \ 8)
            checkboxAi(i).Top = 20 + (i Mod 8) * 20
            GroupBox1.Controls.Add(checkboxAi(i))

            textboxAiValue(i) = New TextBox
            textboxAiValue(i).Width = 50
            textboxAiValue(i).Left = 20 + 55 * (i Mod 8)
            textboxAiValue(i).Top = 20 + (i \ 8) * 60
            GroupBox2.Controls.Add(textboxAiValue(i))
        Next

        For i = 0 To 7
            checkboxAi(i).Checked = True
        Next

        btnStop.Enabled = False
        bRun = False

    End Sub

    Private Sub btnStart_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnStart.Click

        Dim i As Integer
        Dim j As Integer
        Dim temp As Integer
        Dim SN(8) As Byte

        '获取设备索引号
        DevIndex = comboboxDeviceIndex.SelectedIndex

        '打开指定索引号的设备
        temp = USB3OpenDevice(DevIndex)

        '显示设备序列号
        temp = USB3GetDeviceSN(DevIndex, SN(0))
        textboxSN.Text = "SN: " + System.Text.Encoding.ASCII.GetString(SN)

        '-----------------------------------------
        'Ai 相关的设置

        '对 24 个通道进行配置
        For i = 0 To 23
            '选择是否要启用该通道
            temp = SetUSB3AiChanSel(DevIndex, i, CByte(checkboxAi(i).CheckState))
            '设置该通道的量程
            temp = SetUSB3AiRange(DevIndex, i, 10.24)

            '清空所有的 Ai 显示
            textboxAiValue(i).Text = ""
        Next

        '设置采集模式为 连续采集 模式
        temp = SetUSB3AiSampleMode(DevIndex, 0)

        '设置 Ai 输入的接线方式为 NRSE
        temp = SetUSB3AiConnectType(DevIndex, 1)

        '设置 Ai 输入的采样周期为 10000 ns，即 10us，采样率为 100kHz
        temp = SetUSB3AiSampleRate(DevIndex, 10000)

        '设置 Ai 触发源为软件触发
        temp = SetUSB3AiTrigSource(DevIndex, 0)

        '设置 Ai 采样时钟为 Ai 内部采样时钟
        temp = SetUSB3AiConvSource(DevIndex, 0)

        '设置 Ai 预触发点数为 0
        temp = SetUSB3AiPreTrigPoints(DevIndex, 0)

        '清空一次 AiFifo
        temp = SetUSB3ClrAiFifo(DevIndex)

        '启动一次软件触发
        temp = SetUSB3AiSoftTrig(DevIndex)


        '启动 Timer1
        Timer1.Interval = 5
        Timer1.Enabled = True
        btnStart.Enabled = False
        btnStop.Enabled = True
        bRun = True

    End Sub

    Private Sub Timer1_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Timer1.Tick

        Dim i As Integer
        Dim j As Integer
        Dim temp As Integer
        Static Dim ai(4800000) As Single
        Dim di(100) As Byte
        Dim average As Single

        '------------------------------------------------
        'Analog Input 相关的功能

        '从 AiFifo 中每个通道读出 1000 个数，存放在 ai 数组中
        '每次读出来的数据连在一起，将是连续无间断采集得到的一组数据
        temp = USB3GetAi(DevIndex, 1000, ai(0), 1000)

        '显示 AiFifo 中还有多少个数据点没被读出来
        '在长时间连续无间断采集的应用中，需注意 temp 数值的变化
        '如果 temp 值在逐渐增大，说明数据处理速度不够快，导致了数据积压在 AiFifo 中
        textboxFifoNum.Text = temp

        temp = 0
        '计算本次采集一共选择了多少个通道
        For i = 0 To 23
            temp = temp + CByte(checkboxAi(i).CheckState)
        Next

        '计算各个通道测量电压的平均值，并显示
        For j = 0 To temp - 1
            average = 0
            For i = 0 To 999
                average = average + ai(j * 1000 + i)
            Next
            average = average / 1000
            textboxAiValue(j).Text = Format(average, "0.0000")
        Next

    End Sub

    Private Sub btnStop_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnStop.Click

        CloseDevice

    End Sub

    Private Sub Form1_FormClosing(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles MyBase.FormClosing

        If bRun = True Then
            CloseDevice
        End If

    End Sub

    Private Sub CloseDevice()

        Dim temp As Integer

        Timer1.Enabled = False
        Sleep(100)

        '清除硬件触发标志
        temp = SetUSB3ClrAiTrigger(DevIndex)
        '清空 Ai Fifo
        temp = SetUSB3ClrAiFifo(DevIndex)

        '关闭设备
        temp = USB3CloseDevice(DevIndex)

        btnStart.Enabled = True
        btnStop.Enabled = False
        bRun = False

    End Sub
End Class
